@@ -5,7 +5,7 @@ from django.db import transaction
 from django.db.models import Q
 from django.utils.formats import date_format
 from django.utils.timezone import make_aware, now
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from pretix.base.email import get_email_context
 from pretix.base.i18n import language
 from pretix.base.models import Order, OrderPosition, Quota
@@ -102,7 +102,7 @@ def schedule_second_dose(self, event, op):
         op, target_event, itemconf.second_item
     )
 
-    logger.info(f"SECOND DOSE: date after {earliest_date}, target_event {target_event.slug}, target_item {target_item.pk}, target_variation {target_var.pk if target_var else None}")
+    logger.info(f"SECOND DOSE: date after {earliest_date}, target_event {target_event.slug}, target_item {target_item.pk if target_item else None}, target_variation {target_var.pk if target_var else None}")
 
     if target_item is None:
         return
