@@ -1,28 +1,28 @@
-from django.conf.urls import url
+from django.urls import path, re_path
 
 from . import api
 from .views import SelfServiceBookingView, SelfServiceIndexView, SettingsView
 
 urlpatterns = [
-    url(
-        r"^control/event/(?P<organizer>[^/]+)/(?P<event>[^/]+)/settings/vacc_autosched/$",
+    path(
+        "control/event/<str:organizer>/<str:event>/settings/vacc_autosched/",
         SettingsView.as_view(),
         name="settings",
     ),
-    url(
-        r"^api/v1/organizers/(?P<organizer>[^/]+)/events/(?P<event>[^/]+)/items/(?P<item>[^/]+)/vacc_autosched/$",
+    path(
+        "api/v1/organizers/<str:organizer>/events/<str:event>/items/<str:item>/vacc_autosched/",
         api.ItemView.as_view(),
         name="api.item",
     ),
 ]
 
 event_patterns = [
-    url(
-        r"^2nd/(?P<order>[^/]+)/$",
+    path(
+        "2nd/<str:order>/",
         SelfServiceBookingView.as_view(),
         name="second.booking",
     ),
-    url(
+    re_path(
         r"^2nd/?$",
         SelfServiceIndexView.as_view(),
         name="second.index",
